==> webkitgtk-2.7.2.tar.xz: webkitgtk-2.7.2/Source/WebCore/bindings/gobject/GObjectNodeFilterCondition.h <==
/*
 *  Copyright (C) 2014 Igalia S.L.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef GObjectNodeFilterCondition_h
#define GObjectNodeFilterCondition_h

#include "NodeFilterCondition.h"

#include "WebKitDOMNodeFilter.h"
#include <wtf/PassRefPtr.h>
#include <wtf/RetainPtr.h>
#include <wtf/gobject/GRefPtr.h>

namespace WebCore {
class Node;

class GObjectNodeFilterCondition : public NodeFilterCondition {
public:

    static PassRefPtr<GObjectNodeFilterCondition> create(WebKitDOMNodeFilter* filter)
    {
        return adoptRef(new GObjectNodeFilterCondition(filter));
    }

    virtual short acceptNode(JSC::ExecState*, Node*) const;

private:
    GObjectNodeFilterCondition(WebKitDOMNodeFilter* filter)
        : m_filter(filter)
    {
    }
    ~GObjectNodeFilterCondition();

    GRefPtr<WebKitDOMNodeFilter> m_filter;
};

} // namespace WebCore

#endif // GObjectNodeFilterCondition_h

==> webkitgtk-2.13.2.tar.xz: webkitgtk-2.13.2/Source/WebCore/bindings/gobject/GObjectNodeFilterCondition.h <==
/*
 *  Copyright (C) 2014 Igalia S.L.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef GObjectNodeFilterCondition_h
#define GObjectNodeFilterCondition_h

#include "NodeFilterCondition.h"

#include "WebKitDOMNodeFilter.h"
#include <wtf/RetainPtr.h>
#include <wtf/glib/GRefPtr.h>

namespace WebCore {
class Node;

class GObjectNodeFilterCondition : public NodeFilterCondition {
public:

    static Ref<GObjectNodeFilterCondition> create(WebKitDOMNodeFilter* filter)
    {
        return adoptRef(*new GObjectNodeFilterCondition(filter));
    }

    short acceptNode(Node*) const override;

private:
    GObjectNodeFilterCondition(WebKitDOMNodeFilter* filter)
        : m_filter(filter)
    {
    }
    ~GObjectNodeFilterCondition();

    GRefPtr<WebKitDOMNodeFilter> m_filter;
};

} // namespace WebCore

#endif // GObjectNodeFilterCondition_h
